==> wow-opentelemetry-1.15.4-sources.jar: me/ahoo/wow/opentelemetry/messaging/TracingEventBus.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.opentelemetry.messaging

import io.opentelemetry.instrumentation.api.instrumenter.Instrumenter
import me.ahoo.wow.event.DistributedDomainEventBus
import me.ahoo.wow.event.DomainEventStream
import me.ahoo.wow.event.EventStreamExchange
import me.ahoo.wow.event.LocalDomainEventBus

class TracingLocalEventBus(
    override val delegate: LocalDomainEventBus,
    override val producerInstrumenter: Instrumenter<DomainEventStream, Unit> = EventProducerInstrumenter.INSTRUMENTER,
) :
    TracingMessageBus<DomainEventStream, EventStreamExchange, LocalDomainEventBus>,
    LocalDomainEventBus

class TracingDistributedEventBus(
    override val delegate: DistributedDomainEventBus,
    override val producerInstrumenter: Instrumenter<DomainEventStream, Unit> = EventProducerInstrumenter.INSTRUMENTER,
) :
    TracingMessageBus<DomainEventStream, EventStreamExchange, DistributedDomainEventBus>,
    DistributedDomainEventBus

==> wow-opentelemetry-3.10.0-sources.jar: me/ahoo/wow/opentelemetry/messaging/TracingEventBus.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.opentelemetry.messaging

import io.opentelemetry.instrumentation.api.instrumenter.Instrumenter
import me.ahoo.wow.event.DistributedDomainEventBus
import me.ahoo.wow.event.DomainEventStream
import me.ahoo.wow.event.EventStreamExchange
import me.ahoo.wow.event.LocalDomainEventBus

class TracingLocalEventBus(
    override val delegate: LocalDomainEventBus,
    override val producerInstrumenter: Instrumenter<DomainEventStream, Unit> = EventProducerInstrumenter.INSTRUMENTER
) :
    TracingMessageBus<DomainEventStream, EventStreamExchange, LocalDomainEventBus>,
    LocalDomainEventBus

class TracingDistributedEventBus(
    override val delegate: DistributedDomainEventBus,
    override val producerInstrumenter: Instrumenter<DomainEventStream, Unit> = EventProducerInstrumenter.INSTRUMENTER
) :
    TracingMessageBus<DomainEventStream, EventStreamExchange, DistributedDomainEventBus>,
    DistributedDomainEventBus
